@@ -14,4 +14,4 @@ def test_cps_dataset_generates(year):
 @pytest.mark.dependency(depends=["cps"])
 @pytest.mark.parametrize("year", CPS_YEARS)
 def test_cps_openfisca_us_compatible(year):
-    Microsimulation(dataset=CPS, year=year).calc("tax")
+    Microsimulation(dataset=CPS, year=year).calc("employment_income")
