@@ -6,7 +6,7 @@ class ctc_maximum(Variable):
     entity = TaxUnit
     label = "Maximum CTC"
     unit = USD
-    documentation = "Maximum value of the Child Tax Credit, before phaseout."
+    documentation = "Maximum value of the Child Tax Credit, before phase-out."
     definition_period = YEAR
 
     formula = sum_of_variables(["ctc_individual_maximum"])
