@@ -15,7 +15,7 @@ class wic(Variable):
 
     def formula(person, period, parameters):
         meets_income_test = person.spm_unit("meets_wic_income_test", period)
-        meets_categorical_test = person.spm_unit(
+        meets_categorical_test = person(
             "meets_wic_categorical_eligibility", period
         )
         category = person("wic_category_str", period)
